@@ -13,6 +13,8 @@
 import gi
 gi.require_version('Gtk', '3.0')
 gi.require_version('Gst', '1.0')
+gi.require_version('GstAudio', '1.0')
+gi.require_version('GstPbutils', '1.0')
 gi.require_version('Notify', '0.7')
 gi.require_version('TotemPlParser', '1.0')
 from gi.repository import Gtk, Gio, GLib, Gdk, Notify, TotemPlParser
@@ -47,9 +49,7 @@ from lollypop.database_artists import ArtistsDatabase
 from lollypop.database_genres import GenresDatabase
 from lollypop.database_tracks import TracksDatabase
 from lollypop.playlists import Playlists
-from lollypop.radios import Radios
 from lollypop.collectionscanner import CollectionScanner
-from lollypop.fullscreen import FullScreen
 
 
 class Application(Gtk.Application):
@@ -109,6 +109,7 @@ class Application(Gtk.Application):
         """
             Init main application
         """
+        self.__is_fs = False
         if Gtk.get_minor_version() > 18:
             cssProviderFile = Gio.File.new_for_uri(
                 'resource:///org/gnome/Lollypop/application.css')
@@ -151,16 +152,6 @@ class Application(Gtk.Application):
             from lollypop.notification import NotificationManager
             self.notify = NotificationManager()
 
-        self.charts = None
-        if self.settings.get_value('network-search'):
-            from shutil import which
-            if which("youtube-dl") is not None:
-                from lollypop.charts import Charts
-                self.charts = Charts()
-                self.charts.update()
-            else:
-                self.settings.set_value('network-search',
-                                        GLib.Variant('b', False))
         settings = Gtk.Settings.get_default()
         dark = self.settings.get_value('dark-ui')
         settings.set_property('gtk-application-prefer-dark-theme', dark)
@@ -170,7 +161,7 @@ class Application(Gtk.Application):
 
         self.add_action(self.settings.create_action('shuffle'))
 
-        self.__is_fs = False
+        self.db.upgrade()
 
     def do_startup(self):
         """
@@ -212,6 +203,16 @@ class Application(Gtk.Application):
             else:
                 from lollypop.inhibitor_legacy import Inhibitor
             self.inhibitor = Inhibitor()
+            self.charts = None
+            if self.settings.get_value('network-search'):
+                from shutil import which
+                if which("youtube-dl") is not None:
+                    from lollypop.charts import Charts
+                    self.charts = Charts()
+                    self.charts.update()
+                else:
+                    self.settings.set_value('network-search',
+                                            GLib.Variant('b', False))
 
     def prepare_to_exit(self, action=None, param=None):
         """
@@ -225,6 +226,7 @@ class Application(Gtk.Application):
             if self.player.current_track.id is None:
                 track_id = -1
             elif self.player.current_track.id == Type.RADIOS:
+                from lollypop.radios import Radios
                 radios = Radios()
                 track_id = radios.get_id(
                                     self.player.current_track.album_artists[0])
@@ -271,6 +273,7 @@ class Application(Gtk.Application):
             return
         self.db.del_tracks(self.tracks.get_non_persistent())
         try:
+            from lollypop.radios import Radios
             with SqlCursor(self.db) as sql:
                 sql.execute('VACUUM')
             with SqlCursor(self.playlists) as sql:
@@ -394,6 +397,7 @@ class Application(Gtk.Application):
             @param param as GLib.Variant
         """
         if self.window and not self.__is_fs:
+            from lollypop.fullscreen import FullScreen
             fs = FullScreen(self, self.window)
             fs.connect("destroy", self.__on_fs_destroyed)
             self.__is_fs = True
