@@ -31,11 +31,9 @@ class CollectionScanner(GObject.GObject, TagReader):
     """
     __gsignals__ = {
         'scan-finished': (GObject.SignalFlags.RUN_FIRST, None, ()),
-        'artist-updated': (GObject.SignalFlags.RUN_FIRST, None, (int,
-                                                                 int,
-                                                                 bool)),
+        'artist-updated': (GObject.SignalFlags.RUN_FIRST, None, (int, bool)),
         'genre-updated': (GObject.SignalFlags.RUN_FIRST, None, (int, bool)),
-        'album-updated': (GObject.SignalFlags.RUN_FIRST, None, (int,))
+        'album-updated': (GObject.SignalFlags.RUN_FIRST, None, (int, bool))
     }
 
     def __init__(self):
@@ -89,9 +87,11 @@ class CollectionScanner(GObject.GObject, TagReader):
         """
             Return all tracks/dirs for paths
             @param paths as string
-            @return ([tracks path], [dirs path], track count)
+            @return (track path as [str], track dirs as [str],
+                     ignore dirs as [str])
         """
         tracks = []
+        ignore_dirs = []
         track_dirs = list(paths)
         for path in paths:
             tracks_for_path = []
@@ -114,12 +114,12 @@ class CollectionScanner(GObject.GObject, TagReader):
                     except Exception as e:
                         print("CollectionScanner::__get_objects_for_paths: %s"
                               % e)
-            # If a path is empty, return nothing
+            # If a path is empty
             # Ensure user is not doing something bad
             if not tracks_for_path:
-                return ([], [])
+                ignore_dirs.append(GLib.filename_to_uri(path))
             tracks += tracks_for_path
-        return (tracks, track_dirs)
+        return (tracks, track_dirs, ignore_dirs)
 
     def __update_progress(self, current, total):
         """
@@ -148,15 +148,15 @@ class CollectionScanner(GObject.GObject, TagReader):
         if self.__history is None:
             self.__history = History()
         mtimes = Lp().tracks.get_mtimes()
-        orig_tracks = Lp().tracks.get_uris()
+        (new_tracks, new_dirs, ignore_dirs) = self.__get_objects_for_paths(
+                                                                         paths)
+        orig_tracks = Lp().tracks.get_uris(ignore_dirs)
         was_empty = len(orig_tracks) == 0
 
-        (new_tracks, new_dirs) = self.__get_objects_for_paths(paths)
-        if not new_tracks:
+        if ignore_dirs:
             if Lp().notify is not None:
                 Lp().notify.send(_("Lollypop is detecting an empty folder."),
                                  _("Check your music settings."))
-            return
         count = len(new_tracks) + len(orig_tracks)
         # Add monitors on dirs
         if self.__inotify is not None:
@@ -261,23 +261,22 @@ class CollectionScanner(GObject.GObject, TagReader):
         # If nothing in stats, set mtime
         if amtime == 0:
             amtime = mtime
+
         debug("CollectionScanner::add2db(): Add artists %s" % artists)
-        (artist_ids, new_artist_ids) = self.add_artists(artists,
-                                                        album_artists,
-                                                        a_sortnames)
+        artist_ids = self.add_artists(artists, album_artists, a_sortnames)
+
         debug("CollectionScanner::add2db(): "
               "Add album artists %s" % album_artists)
-        (album_artist_ids, new_album_artist_ids) = self.add_album_artists(
-                                                                 album_artists,
-                                                                 aa_sortnames)
-        new_artist_ids += new_album_artist_ids
+        album_artist_ids = self.add_album_artists(album_artists, aa_sortnames)
+
+        new_artist_ids = list(set(album_artist_ids) | set(artist_ids))
 
         debug("CollectionScanner::add2db(): Add album: "
               "%s, %s" % (album_name, album_artist_ids))
         (album_id, new_album) = self.add_album(album_name, album_artist_ids,
                                                path, album_pop, amtime)
 
-        (genre_ids, new_genre_ids) = self.add_genres(genres, album_id)
+        genre_ids = self.add_genres(genres, album_id)
 
         # Add track to db
         debug("CollectionScanner::add2db(): Add track")
@@ -289,15 +288,13 @@ class CollectionScanner(GObject.GObject, TagReader):
         debug("CollectionScanner::add2db(): Update tracks")
         self.update_track(track_id, artist_ids, genre_ids)
         self.update_album(album_id, album_artist_ids, genre_ids, year)
-        # Notify about new artists/genres
-        if new_genre_ids or new_artist_ids:
+        if new_album:
             with SqlCursor(Lp().db) as sql:
                 sql.commit()
-            for genre_id in new_genre_ids:
-                GLib.idle_add(self.emit, 'genre-updated', genre_id, True)
-            for artist_id in new_artist_ids:
-                GLib.idle_add(self.emit, 'artist-updated',
-                              artist_id, album_id, True)
+        for genre_id in genre_ids:
+            GLib.idle_add(self.emit, 'genre-updated', genre_id, True)
+        for artist_id in new_artist_ids:
+            GLib.idle_add(self.emit, 'artist-updated', artist_id, True)
         return track_id
 
     def __del_from_db(self, uri):
@@ -321,17 +318,14 @@ class CollectionScanner(GObject.GObject, TagReader):
                            ltime, mtime, album_popularity)
         Lp().tracks.remove(track_id)
         Lp().tracks.clean(track_id)
-        modified = Lp().albums.clean(album_id)
-        if modified:
+        deleted = Lp().albums.clean(album_id)
+        if deleted:
             with SqlCursor(Lp().db) as sql:
                 sql.commit()
-            GLib.idle_add(self.emit, 'album-updated', album_id)
+            GLib.idle_add(self.emit, 'album-updated', album_id, True)
         for artist_id in album_artist_ids + artist_ids:
-            ret = Lp().artists.clean(artist_id)
-            if ret:
-                GLib.idle_add(self.emit, 'artist-updated',
-                              artist_id, album_id, False)
+            Lp().artists.clean(artist_id)
+            GLib.idle_add(self.emit, 'artist-updated', artist_id, False)
         for genre_id in genre_ids:
-            ret = Lp().genres.clean(genre_id)
-            if ret:
-                GLib.idle_add(self.emit, 'genre-updated', genre_id, False)
+            Lp().genres.clean(genre_id)
+            GLib.idle_add(self.emit, 'genre-updated', genre_id, False)
