@@ -14,6 +14,7 @@ from gi.repository import Gst, GstAudio, GstPbutils, GLib, Gio
 
 from time import time
 from threading import Thread
+from re import sub
 
 from lollypop.player_base import BasePlayer
 from lollypop.tagreader import TagReader
@@ -80,8 +81,11 @@ class BinPlayer(BasePlayer):
         if self.__preview is not None:
             output = Lp().settings.get_value('preview-output').get_string()
             pulse = Gst.ElementFactory.make('pulsesink', 'output')
-            pulse.set_property('device', output)
-            self.__preview.set_property('audio-sink', pulse)
+            if pulse is None:
+                pulse = Gst.ElementFactory.make('alsasink', 'output')
+            if pulse is not None:
+                pulse.set_property('device', output)
+                self.__preview.set_property('audio-sink', pulse)
 
     def is_playing(self):
         """
@@ -272,19 +276,12 @@ class BinPlayer(BasePlayer):
             # Force widgets to update (spinners)
             self.emit('current-changed')
             return False
-        argv = ["youtube-dl", "-g", "-f", "bestaudio", track.uri, None]
         try:
             if play:
-                self.emit('loading-changed')
-            (s, pid, i, o, err) = GLib.spawn_async_with_pipes(
-                                       None, argv, None,
-                                       GLib.SpawnFlags.SEARCH_PATH |
-                                       GLib.SpawnFlags.DO_NOT_REAP_CHILD, None)
-            io = GLib.IOChannel(o)
-            io.add_watch(GLib.IO_IN | GLib.IO_HUP,
-                         self.__set_gv_uri,
-                         track, play,
-                         priority=GLib.PRIORITY_HIGH)
+                self.emit('loading-changed', True)
+            t = Thread(target=self.__youtube_dl_lookup, args=(track, play))
+            t.daemon = True
+            t.start()
             return True
         except Exception as e:
             self._current_track = Track()
@@ -310,11 +307,10 @@ class BinPlayer(BasePlayer):
             # We can scrobble if the track has been played
             # for at least half its duration, or for 4 minutes
             if played >= finished.duration / 2 or played >= 240:
-                Lp().lastfm.scrobble(artists,
-                                     finished.album_name,
-                                     finished.title,
-                                     int(finished_start_time),
-                                     int(finished.duration))
+                Lp().lastfm.do_scrobble(artists,
+                                        finished.album_name,
+                                        finished.title,
+                                        int(finished_start_time))
 
     def _on_stream_start(self, bus, message):
         """
@@ -611,19 +607,36 @@ class BinPlayer(BasePlayer):
             Lp().tracks.set_more_popular(finished.id)
             Lp().albums.set_more_popular(finished.album_id)
 
-    def __set_gv_uri(self, io, condition, track, play):
+    def __youtube_dl_lookup(self, track, play):
         """
+            Launch youtube-dl to get video url
+            @param track as Track
+            @param play as bool
+        """
+        # Remove playlist args
+        uri = sub("list=.*", "", track.uri)
+        argv = ["youtube-dl", "-g", "-f", "bestaudio", uri, None]
+        (s, o, e, s) = GLib.spawn_sync(None,
+                                       argv,
+                                       None,
+                                       GLib.SpawnFlags.SEARCH_PATH,
+                                       None)
+        if o:
+            GLib.idle_add(self.__set_gv_uri, o.decode("utf-8"), track, play)
+        else:
+            if Lp().notify:
+                Lp().notify.send(e.decode("utf-8"))
+            print("BinPlayer::__youtube_dl_lookup:", e.decode("utf-8"))
+            if play:
+                GLib.idle_add(self.emit, 'loading-changed', False)
+
+    def __set_gv_uri(self, uri, track, play):
+        """
             Play uri for io
-            @param io as GLib.IOChannel
-            @param condition as Constant
+            @param uri as str
             @param track as Track
             @param play as bool
         """
-        uri = io.readline()
-        if not uri:
-            print("youtube-dl failed to get video uri")
-            return
         track.set_uri(uri)
         if play:
             self.load(track)
-        return False
