@@ -18,7 +18,7 @@ from threading import Thread
 
 from lollypop.widgets_rating import RatingWidget
 from lollypop.widgets_loved import LovedWidget
-from lollypop.define import Lp
+from lollypop.define import Lp, Type
 from lollypop.sqlcursor import SqlCursor
 from lollypop.objects import Track, Album
 from lollypop import utils
@@ -382,17 +382,18 @@ class EditMenu(BaseMenu):
     """
     __TAG_EDITORS = ['exfalso', 'easytag', 'picard', 'puddletag', 'kid3-qt']
 
-    def __init__(self, object_id, is_youtube):
+    def __init__(self, object_id, is_album, is_youtube):
         """
             Init edit menu
             @param object id as int
+            @param is album as int
             @param is youtube as bool
         """
-        BaseMenu.__init__(self, object_id, [], [], True)
+        BaseMenu.__init__(self, object_id, [], [], is_album)
 
         if is_youtube:
             self.__set_remove_action()
-        else:
+        elif is_album:
             favorite = Lp().settings.get_value('tag-editor').get_string()
             for editor in [favorite] + self.__TAG_EDITORS:
                 if which(editor) is not None:
@@ -407,11 +408,13 @@ class EditMenu(BaseMenu):
         """
             Remove album
         """
-        remove_album_action = Gio.SimpleAction(name="remove_album_action")
-        Lp().add_action(remove_album_action)
-        remove_album_action.connect('activate',
-                                    self.__remove_album)
-        self.append(_("Remove album"), 'app.remove_album_action')
+        remove_action = Gio.SimpleAction(name="remove_action")
+        Lp().add_action(remove_action)
+        remove_action.connect('activate', self.__remove_object)
+        if self._is_album:
+            self.append(_("Remove album"), 'app.remove_action')
+        else:
+            self.append(_("Remove track"), 'app.remove_action')
 
     def __set_edit_actions(self):
         """
@@ -419,40 +422,45 @@ class EditMenu(BaseMenu):
         """
         edit_tag_action = Gio.SimpleAction(name="edit_tag_action")
         Lp().add_action(edit_tag_action)
-        edit_tag_action.connect('activate',
-                                self.__edit_tag)
+        edit_tag_action.connect('activate', self.__edit_tag)
         self.append(_("Modify information"), 'app.edit_tag_action')
 
-    def __remove_album(self, action, variant):
+    def __remove_object(self, action, variant):
         """
             Remove album
             @param SimpleAction
             @param GVariant
         """
-        album = Album(self._object_id)
-        art_file = Lp().art.get_album_cache_name(album)
         artist_ids = []
-        for track_id in album.track_ids:
-            artist_ids += Lp().tracks.get_artist_ids(track_id)
-            Lp().tracks.remove(track_id)
-            Lp().tracks.clean(track_id)
+        if self._is_album:
+            album = Album(self._object_id)
+            for track_id in album.track_ids:
+                artist_ids += Lp().tracks.get_artist_ids(track_id)
+                Lp().tracks.remove(track_id)
+                Lp().tracks.clean(track_id)
+                art_file = Lp().art.get_album_cache_name(album)
+                Lp().art.clean_store(art_file)
+        else:
+            track = Track(self._object_id)
+            album = track.album
+            artist_ids = Lp().tracks.get_artist_ids(track.id)
+            Lp().tracks.remove(track.id)
+            Lp().tracks.clean(track.id)
         artist_ids += album.artist_ids
         genre_ids = Lp().albums.get_genre_ids(album.id)
-        Lp().albums.clean(album.id)
+        deleted = Lp().albums.clean(album.id)
         for artist_id in list(set(artist_ids)):
-            ret = Lp().artists.clean(artist_id)
-            if ret:
-                GLib.idle_add(Lp().scanner.emit, 'artist-updated',
-                              artist_id, album.id, False)
+            Lp().artists.clean(artist_id)
+            # Do not check clean return
+            GLib.idle_add(Lp().scanner.emit, 'artist-updated',
+                          artist_id, False)
         for genre_id in genre_ids:
-            ret = Lp().genres.clean(genre_id)
-            if ret:
-                GLib.idle_add(Lp().scanner.emit, 'genre-updated',
-                              genre_id, False)
+            Lp().genres.clean(genre_id)
+            GLib.idle_add(Lp().scanner.emit, 'genre-updated',
+                          genre_id, False)
         with SqlCursor(Lp().db) as sql:
             sql.commit()
-        GLib.idle_add(Lp().scanner.emit, 'album-updated', self._object_id)
-        Lp().art.clean_store(art_file)
+        GLib.idle_add(Lp().scanner.emit, 'album-updated', album.id, deleted)
 
     def __edit_tag(self, action, variant):
         """
@@ -473,15 +481,17 @@ class AlbumMenu(Gio.Menu):
         Contextual menu for album
     """
 
-    def __init__(self, album):
+    def __init__(self, album, show_artist=False):
         """
             Init menu model
             @param album as Album
+            @param show artist menu as bool
         """
         Gio.Menu.__init__(self)
-        self.insert_section(0, _("Artist"),
-                            ArtistMenu(album.id, album.genre_ids,
-                                       album.artist_ids, True))
+        if show_artist:
+            self.insert_section(0, _("Artist"),
+                                ArtistMenu(album.id, album.genre_ids,
+                                           album.artist_ids, True))
         self.insert_section(1, _("Queue"),
                             QueueMenu(album.id, album.genre_ids,
                                       album.artist_ids, True))
@@ -489,7 +499,7 @@ class AlbumMenu(Gio.Menu):
                             PlaylistsMenu(album.id, album.genre_ids,
                                           album.artist_ids, True))
         self.insert_section(3, _("Edit"),
-                            EditMenu(album.id, album.is_youtube))
+                            EditMenu(album.id, True, album.is_youtube))
 
 
 class TrackMenu(Gio.Menu):
@@ -507,6 +517,9 @@ class TrackMenu(Gio.Menu):
                             QueueMenu(track.id, [], [], False))
         self.insert_section(1, _("Playlists"),
                             PlaylistsMenu(track.id, [], [], False))
+        if track.album.is_youtube:
+            self.insert_section(3, _("Edit"),
+                                EditMenu(track.id, False, True))
 
 
 class TrackMenuPopover(Gtk.Popover):
@@ -529,18 +542,6 @@ class TrackMenuPopover(Gtk.Popover):
         else:
             track_year = ""
 
-        if track.album.is_youtube:
-            uri = Lp().tracks.get_uri(track.id)
-            edit = Gtk.Entry()
-            edit.set_margin_start(5)
-            edit.set_margin_end(5)
-            edit.set_margin_bottom(5)
-            edit.set_tooltip_text(_("Youtube video address"))
-            edit.set_property('hexpand', True)
-            edit.set_text(uri)
-            edit.connect('changed', self.__on_edit_changed, track.id)
-            edit.show()
-
         rating = RatingWidget(track)
         rating.set_margin_top(5)
         rating.set_margin_bottom(5)
@@ -580,6 +581,16 @@ class TrackMenuPopover(Gtk.Popover):
             youtube.set_margin_end(5)
             youtube.set_tooltip_text(uri)
             youtube.show_all()
+            uri = "https://www.youtube.com/results?search_query=%s" %\
+                (track.artists[0] + " " + track.name,)
+            search = Gtk.LinkButton(uri)
+            icon = Gtk.Image.new_from_icon_name('edit-find-symbolic',
+                                                Gtk.IconSize.MENU)
+            search.set_image(icon)
+            search.get_style_context().add_class('no-padding')
+            search.set_margin_end(5)
+            search.set_tooltip_text(uri)
+            search.show_all()
 
         # Hack to add two widgets in popover
         # Use a Gtk.PopoverMenu later (GTK>3.16 available on Debian stable)
@@ -594,20 +605,32 @@ class TrackMenuPopover(Gtk.Popover):
         if menu_widget is not None:
             menu_widget.reparent(grid)
 
-        separator = Gtk.Separator()
-        separator.show()
+        if not track.album.is_youtube:
+            separator = Gtk.Separator()
+            separator.show()
+            grid.add(separator)
 
-        grid.add(separator)
         hgrid = Gtk.Grid()
         hgrid.add(rating)
         hgrid.add(loved)
         if track.album.is_youtube:
             hgrid.add(youtube)
+            hgrid.add(search)
         if track_year != "":
             hgrid.add(year)
         hgrid.show()
         if track.album.is_youtube:
             grid.set_row_spacing(2)
+            uri = Lp().tracks.get_uri(track.id)
+            edit = Gtk.Entry()
+            edit.set_margin_start(5)
+            edit.set_margin_end(5)
+            edit.set_margin_bottom(5)
+            edit.set_tooltip_text(_("YouTube video address"))
+            edit.set_property('hexpand', True)
+            edit.set_text(uri)
+            edit.connect('changed', self.__on_edit_changed, track.id)
+            edit.show()
             grid.add(edit)
         grid.add(hgrid)
         self.add(stack)
@@ -647,7 +670,7 @@ class AlbumMenuPopover(Gtk.Popover):
         edit.set_property('halign', Gtk.Align.CENTER)
         genres = ", ".join(Lp().albums.get_genres(album.id))
         if not genres:
-            genres = "Youtube"
+            genres = "YouTube"
         edit.set_text(genres)
         edit.show()
 
@@ -700,8 +723,10 @@ class AlbumMenuPopover(Gtk.Popover):
             @param edit as Gtk.Edit
             @param album as Album
         """
-        orig_genre_ids = Lp().albums.get_genre_ids(album.id)
         genre = edit.get_text()
+        if not genre:
+            return
+        orig_genre_ids = Lp().albums.get_genre_ids(album.id)
         genre_id = Lp().genres.get_id(genre)
         if genre_id is None:
             genre_id = Lp().genres.add(genre)
@@ -712,10 +737,10 @@ class AlbumMenuPopover(Gtk.Popover):
             Lp().tracks.del_genres(track_id)
             Lp().tracks.add_genre(track_id, genre_id)
         for genre_id in orig_genre_ids:
-            ret = Lp().genres.clean(genre_id)
-            if ret:
+            if genre_id != Type.CHARTS:
+                Lp().genres.clean(genre_id)
                 GLib.idle_add(Lp().scanner.emit, 'genre-updated',
                               genre_id, False)
         with SqlCursor(Lp().db) as sql:
             sql.commit()
-        Lp().scanner.emit('album-updated', album.id)
+        Lp().scanner.emit('album-updated', album.id, True)
