@@ -82,6 +82,7 @@ class SelectionList(Gtk.Bin):
         self.__timeout = None
         self.__to_select_ids = []
         self.__modifier = False
+        self.__populating = False
         self.__updating = False       # Sort disabled if False
         self.__is_artists = False
         self.__fast_scroll = fast_scroll  # Show button to scroll to top
@@ -161,11 +162,15 @@ class SelectionList(Gtk.Bin):
             @param [(int, str)], will be deleted
             @thread safe
         """
+        if self.__populating:
+            return
+        self.__populating = True
         if len(self.__model) > 0:
             self.__updating = True
         self.__add_values(values)
         self.emit('populated')
         self.__updating = False
+        self.__populating = False
 
     def remove_value(self, object_id):
         """
@@ -176,15 +181,16 @@ class SelectionList(Gtk.Bin):
             if item[0] == object_id:
                 self.__model.remove(item.iter)
                 break
-        # We force selection of first item
-        self.__selection.unselect_all()
-        self.__selection.select_iter(self.__model[0].iter)
 
     def add_value(self, value):
         """
             Add item to list
             @param value as (int, str)
         """
+        # Do not add value if already exists
+        for item in self.__model:
+            if item[0] == value[0]:
+                return
         self.__updating = True
         self.__add_value(value)
         self.__updating = False
@@ -203,7 +209,7 @@ class SelectionList(Gtk.Bin):
                 found = True
                 break
         if not found:
-            self.add_value((object_id, name))
+            self.__add_value((object_id, name))
         self.__updating = False
 
     def update_values(self, values):
@@ -270,7 +276,8 @@ class SelectionList(Gtk.Bin):
         else:
             self.__selection.unselect_all()
 
-    def get_selected_ids(self):
+    @property
+    def selected_ids(self):
         """
             Get selected ids
             @return array of ids as [int]
@@ -477,7 +484,7 @@ class SelectionList(Gtk.Bin):
             @param current as bool
             @return bool
         """
-        ids = self.get_selected_ids()
+        ids = self.selected_ids
         if not ids:
             return True
         elif self.__modifier:
