@@ -10,7 +10,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 
-from gi.repository import Gtk, Gdk, Pango
+from gi.repository import Gtk, Gdk, Pango, Gio
 
 from gettext import gettext as _
 from math import pi
@@ -51,6 +51,9 @@ class ArtistView(ArtistAlbumsView):
         self.__add_button = builder.get_object('add-button')
         self.__play_button = builder.get_object('play-button')
         self.__grid = builder.get_object('header-grid')
+        if Lp().lastfm is None or\
+                not Gio.NetworkMonitor.get_default().get_network_available():
+            builder.get_object('lastfm-button').hide()
         header = builder.get_object('header')
         header.set_property('valign', Gtk.Align.START)
         self._overlay.add_overlay(header)
@@ -113,26 +116,20 @@ class ArtistView(ArtistAlbumsView):
             self.__grid.get_style_context().remove_class('header')
             self.__grid.set_property('valign', Gtk.Align.START)
 
-    def _on_jump_button_clicked(self, widget):
-        """
-            Scroll to album
-        """
-        self.jump_to_current()
-
     def _on_label_realize(self, eventbox):
         """
             Change cursor on label
             @param eventbox as Gtk.EventBox
         """
         if InfoPopover.should_be_shown() and self._artist_ids:
-            eventbox.get_window().set_cursor(Gdk.Cursor(Gdk.CursorType.HAND1))
+            eventbox.get_window().set_cursor(Gdk.Cursor(Gdk.CursorType.HAND2))
 
     def _on_artwork_realize(self, eventbox):
         """
             Change cursor on image
             @param eventbox as Gtk.EventBox
         """
-        eventbox.get_window().set_cursor(Gdk.Cursor(Gdk.CursorType.HAND1))
+        eventbox.get_window().set_cursor(Gdk.Cursor(Gdk.CursorType.HAND2))
 
     def _on_label_button_release(self, eventbox, event):
         """
@@ -199,6 +196,22 @@ class ArtistView(ArtistAlbumsView):
         except:
             pass  # Artist not available anymore for this context
 
+    def _on_jump_button_clicked(self, widget):
+        """
+            Scroll to album
+        """
+        self.jump_to_current()
+
+    def _on_lastfm_button_clicked(self, widget):
+        """
+            Show lastfm similar artists
+        """
+        from lollypop.pop_lastfm import LastfmPopover
+        popover = LastfmPopover()
+        popover.set_relative_to(widget)
+        popover.populate(self._artist_ids)
+        popover.show()
+
     def _on_artwork_draw(self, image, ctx):
         """
             Draw rounded image
