@@ -98,6 +98,12 @@ class Row(Gtk.ListBoxRow):
         self.add(self._row_widget)
         self.get_style_context().add_class('trackrow')
 
+    def show_spinner(self):
+        """
+            Show spinner
+        """
+        self._indicator.show_spinner()
+
     def set_indicator(self, playing, loved):
         """
             Show indicator
@@ -128,6 +134,14 @@ class Row(Gtk.ListBoxRow):
         """
         self.__number = num
 
+    def update_duration(self):
+        """
+            Update duration for row
+        """
+        # Get a new track to get new duration (cache)
+        track = Track(self._track.id)
+        self._duration_label.set_text(seconds_to_string(track.duration))
+
     def update_num_label(self):
         """
             Update position label for row
@@ -143,7 +157,8 @@ class Row(Gtk.ListBoxRow):
             self._num_label.get_style_context().remove_class('queued')
             self._num_label.set_text('')
 
-    def get_id(self):
+    @property
+    def id(self):
         """
             Get object id
             @return Current id as int
@@ -242,7 +257,7 @@ class Row(Gtk.ListBoxRow):
             @param xcoordinate as int (or None)
             @param ycoordinate as int (or None)
         """
-        popover = TrackMenuPopover(self._track.id, TrackMenu(self._track.id))
+        popover = TrackMenuPopover(self._track, TrackMenu(self._track))
         popover.set_relative_to(widget)
         if xcoordinate is not None and ycoordinate is not None:
             rect = widget.get_allocation()
@@ -306,7 +321,10 @@ class PlaylistRow(Row):
         self.__cover = Gtk.Image()
         self.__cover.set_property('halign', Gtk.Align.CENTER)
         self.__cover.set_property('valign', Gtk.Align.CENTER)
-        self.__cover.get_style_context().add_class('small-cover-frame')
+        if self._track.is_youtube:
+            self.__cover.get_style_context().add_class('small-cover-youtube')
+        else:
+            self.__cover.get_style_context().add_class('small-cover-frame')
         self.__cover.set_no_show_all(True)
         # We force width with a Box
         box = Gtk.Box()
@@ -532,7 +550,7 @@ class TracksWidget(Gtk.ListBox):
             @param previous album id as int
         """
         for child in self.get_children():
-            track = Track(child.get_id())
+            track = Track(child.id)
             if track.album.id == prev_album_id:
                 child.show_headers(False)
             else:
@@ -555,8 +573,26 @@ class TracksWidget(Gtk.ListBox):
             @param track id as int
         """
         for row in self.get_children():
-            row.set_indicator(row.get_id() == track_id,
-                              utils.is_loved(row.get_id()))
+            row.set_indicator(row.id == track_id,
+                              utils.is_loved(row.id))
+
+    def update_duration(self, track_id):
+        """
+            Update playing track
+            @param track id as int
+        """
+        for row in self.get_children():
+            if row.id == track_id:
+                row.update_duration()
+
+    def show_spinner(self, track_id):
+        """
+            Show spinner for track_id
+        """
+        for row in self.get_children():
+            if row.id == track_id:
+                row.show_spinner()
+                break
 
 #######################
 # PRIVATE             #
@@ -574,7 +610,7 @@ class TracksWidget(Gtk.ListBox):
         """
         try:
             bottom_row = self.get_children()[-1]
-            bottom_row.emit('track-moved', bottom_row.get_id(),
+            bottom_row.emit('track-moved', bottom_row.id,
                             int(data.get_text()), False)
         except:
             pass
@@ -597,7 +633,7 @@ class TracksWidget(Gtk.ListBox):
             return
 
         for row in self.get_children():
-            if track_id == row.get_id():
+            if track_id == row.id:
                 row.set_indicator(track_id == Lp().player.current_track.id,
                                   utils.is_loved(track_id))
 
@@ -622,4 +658,4 @@ class TracksWidget(Gtk.ListBox):
             @param widget as TracksWidget
             @param row as TrackRow
         """
-        self.emit('activated', row.get_id())
+        self.emit('activated', row.id)
