@@ -20,6 +20,7 @@ from re import findall
 from lollypop.sqlcursor import SqlCursor
 from lollypop.tagreader import TagReader
 from lollypop.objects import Track, Album
+from lollypop.utils import escape
 from lollypop.define import Lp, DbPersistent, GOOGLE_API_ID, Type
 
 
@@ -130,23 +131,25 @@ class Youtube:
                 return (None, None)
         t = TagReader()
         with SqlCursor(Lp().db) as sql:
+            # Happen often with Itunes/Spotify
+            if album_artist not in item.artists:
+                item.artists.append(album_artist)
             artists = "; ".join(item.artists)
-            (artist_ids, new_artist_ids) = t.add_artists(artists,
-                                                         album_artist,
-                                                         "")
-            (album_artist_ids, new_album_artist_ids) = t.add_album_artists(
-                                                               album_artist,
-                                                               "")
+            artist_ids = t.add_artists(artists, album_artist, "")
+            album_artist_ids = t.add_album_artists(album_artist, "")
             (album_id, new_album) = t.add_album(item.album,
                                                 album_artist_ids,
                                                 "", 0, int(time()))
+            # FIXME: Check this, could move this in add_album()
             if new_album:
                 Lp().albums.set_synced(album_id, Type.NONE)
 
             if persistent == DbPersistent.CHARTS:
-                (genre_ids, new_genre_ids) = ([Type.CHARTS], [])
+                genre_ids = [Type.CHARTS]
+                new_artist_ids = []
             else:
-                (genre_ids, new_genre_ids) = t.add_genres("Youtube", album_id)
+                new_artist_ids = list(set(artist_ids) | set(album_artist_ids))
+                genre_ids = t.add_genres("YouTube", album_id)
 
             # Add track to db
             uri = "https://www.youtube.com/watch?v=%s" % yid
@@ -156,14 +159,11 @@ class Youtube:
             t.update_track(track_id, artist_ids, genre_ids)
             t.update_album(album_id, album_artist_ids, genre_ids, None)
             sql.commit()
-        # Notify about new artists/genres
-        if new_genre_ids or new_artist_ids:
-            for genre_id in new_genre_ids:
-                GLib.idle_add(Lp().scanner.emit, 'genre-updated',
-                              genre_id, True)
-            for artist_id in new_artist_ids:
-                GLib.idle_add(Lp().scanner.emit, 'artist-updated',
-                              artist_id, album_id, True)
+
+        for genre_id in genre_ids:
+            GLib.idle_add(Lp().scanner.emit, 'genre-updated', genre_id, True)
+        for artist_id in new_artist_ids:
+            GLib.idle_add(Lp().scanner.emit, 'artist-updated', artist_id, True)
         return (album_id, track_id)
 
     def __get_youtube_id(self, item):
@@ -173,8 +173,20 @@ class Youtube:
         """
         if self.__fallback:
             return self.__get_youtube_id_fallback(item)
-        search = "%s %s" % (item.artists[0],
-                            item.name)
+        # Try to handle compilations (itunes one)
+        if item.artists[0].lower() == "various artists":
+            if len(item.artists) > 1:
+                artist = item.artists[1]
+            else:
+                artist = ""
+        else:
+            artist = item.artists[0]
+        unescaped = "%s %s" % (artist,
+                               item.name)
+        search = GLib.uri_escape_string(
+                            unescaped.replace(' ', '+'),
+                            None,
+                            True)
         key = Lp().settings.get_value('cs-api-key').get_string()
         try:
             # if item.duration >= 1200:
@@ -192,11 +204,35 @@ class Youtube:
             (status, data, tag) = f.load_contents(None)
             if status:
                 decode = json.loads(data.decode('utf-8'))
-                return decode['items'][0]['id']['videoId']
+                dic = {}
+                # Here we are going to look wich youtube title looks
+                # like original title
+                # Start with an impossible bad match
+                best = 10000
+                for i in decode['items']:
+                    title = escape(i['snippet']['title'].lower(), [])
+                    split = escape(item.name, []).split(' ')
+                    # Remove common word for a valid track
+                    title.replace('official', '')
+                    title.replace('video', '')
+                    # Remove part of orig title found in youtube title
+                    for s in split:
+                        title.replace(s.lower(), '')
+                    l = len(title)
+                    if l < best:
+                        best = l
+                    elif l == best:
+                        continue  # Keep first result
+                    dic[l] = i['id']['videoId']
+                # Return url from first dic item
+                if best == 10000:
+                    return None
+                else:
+                    return dic[best]
         except IndexError:
             pass
         except Exception as e:
-            print("Youtube::__get_youtube_id():", e, f.get_uri())
+            print("Youtube::__get_youtube_id():", e)
             self.__fallback = True
             return self.__get_youtube_id_fallback(item)
         return None
@@ -207,8 +243,20 @@ class Youtube:
             @param item as SearchItem
         """
         try:
-            search = "%s %s" % (item.artists[0],
-                                item.name)
+            # Try to handle compilations (itunes one)
+            if item.artists[0].lower() == "various artists":
+                if len(item.artists) > 1:
+                    artist = item.artists[1]
+                else:
+                    artist = ""
+            else:
+                artist = item.artists[0]
+            unescaped = "%s %s" % (artist,
+                                   item.name)
+            search = GLib.uri_escape_string(
+                            unescaped.replace(' ', '+'),
+                            None,
+                            True)
             f = Gio.File.new_for_uri("https://www.youtube.com/"
                                      "results?search_query=%s" % search)
             (status, data, tag) = f.load_contents(None)
@@ -218,7 +266,7 @@ class Youtube:
                 urls = findall(reg, html)
                 return urls[0]
         except Exception as e:
-            print("Youtube::__get_youtube_id_fallback():", e, f.get_uri())
+            print("Youtube::__get_youtube_id_fallback():", e)
             self.__fallback = True
         return None
 
